==> lnl-2.1.8.tar.gz: lnl-2.1.8/src/party_prot.h <==
/* party.c */
void	init_party( void );
void	init_party_debug( void );
item_t	*init_mbr_item(
	mbr_t *mbr, item_kind_t kind, item_kind_dat_t *sub_kind,
	bool_t flg_ident, bool_t curse, bool_t flg_eq
);
void	init_party_auto_mark( void );
void	new_mbr_reset( mbr_t *mbr );
void	new_mbr(
	mbr_t *mbr, char *name, char face,
	race_t race, sex_t sex, long class_n, long ls_mbr_n
);
void	set_mbr_dir( void );
void	appear_party( bool_t flg_clr_map );
void	clr_map_all_mbr( void );
void	set_map_all_mbr( void );
void	act_party( void );
bool_t	chk_auto_mnstr( mbr_t *mbr, long x1, long y1, long x2, long y2 );
bool_t	chk_auto_door_mbr( mbr_t *mbr, long x1, long y1, long x2, long y2 );
void	die_mbr( mbr_t *mbr );
void	act_mbr_auto_mnstr( mbr_t *mbr, long x, long y );
void	mbr_peep_door( mbr_t *mbr, long dr_n );
void	mbr_srch_door( mbr_t *mbr, long dr_n );
void	mbr_srch_trap( mbr_t *mbr, trap_t *trap );
void	mbr_srch_item( mbr_t *mbr, item_t *item );
void	mbr_srch_obj( mbr_t *mbr );
void	clr_party_act( void );
void	join_mbr( long ls_mbr_n, long mbr_n );
void	not_join_mbr( long ls_mbr_n, long mbr_n );
void	collect_gold( mbr_t *mbr );
void	divide_gold( void );
void	exp_party( long exp, bool_t flg_draw );
void	remove_mbr( mbr_t *mbr );
mbr_t	*get_mbr_nearest( long x, long y );
mbr_t	*get_mbr_near( long x, long y );
mbr_t	*get_mbr_disperse( mbr_t *mbr );
mbr_t	*get_mbr_randm( long x, long y );
mbr_t	*get_mbr_stagger( mbr_t *mbr );
bool_t	chk_already_mark( void *p, mbr_t *mbr );
char	*get_race_str( race_t *race );
char	*get_race_name( race_t *race );
long	add_hp_mbr( mbr_t *mbr, long n );
mbr_t	**get_ls_mbr( void );
party_t	*get_party( void );
long	get_mbr_n( long x, long y );
mbr_t	*get_mbr( long x, long y );
flg_party_t	get_flg_party( void );
flg_party_t	set_flg_party( flg_party_t flg );
long	next_mbr( long mbr_n, long add );
long	next_ls_mbr( long ls_mbr_n, long add );
class_t	*get_class_tab( void );
bool_t	remove_class( long class_n );
bool_t	cmp_class( class_t *org, class_t *dst );
char	*get_msg_ttl_auto_mark( long n );
square_t	*get_square_mbr( void );
void	set_square_mbr( square_t *sq );

==> lnl-2.1.20.tar.gz: lnl-2.1.20/src/party_prot.h <==
/* party.c */
void	init_party( void );
void	init_party_debug( void );
item_t	*init_mbr_item(
	mbr_t *mbr, item_kind_t kind, item_kind_dat_t *sub_kind,
	bool_t flg_ident, bool_t curse, bool_t flg_eq
);
void	new_mbr_reset( mbr_t *mbr );
void	new_mbr(
	mbr_t *mbr, char *name, char face,
	race_t race, sex_t sex, long class_n, long ls_mbr_n
);
void	set_mbr_dir( void );
void	appear_party( bool_t flg_clr_map );
void	clr_map_all_mbr( void );
void	set_map_all_mbr( void );
void	move_all_mbr_trgt( void );
void	act_party( void );
bool_t	chk_auto_mnstr( mbr_t *mbr, long x1, long y1, long x2, long y2 );
bool_t	chk_auto_door_mbr( mbr_t *mbr, long x1, long y1, long x2, long y2 );
void	die_mbr( mbr_t *mbr );
bool_t	chk_can_act_mbr( mbr_t *p );
void	set_mbr_act_auto_mnstr( mbr_t *mbr, long x, long y );
void	mbr_peep_door( mbr_t *mbr, long dr_n );
void	mbr_srch_door( mbr_t *mbr, long dr_n );
void	mbr_srch_trap( mbr_t *mbr, trap_t *trap );
void	mbr_srch_item( mbr_t *mbr, item_t *item );
void	mbr_srch_obj( mbr_t *mbr );
bool_t	mbr_srch_obj_sub( mbr_t *mbr, long x, long y );
void	clr_party_act( void );
void	join_mbr( long ls_mbr_n, long mbr_n );
void	not_join_mbr( long ls_mbr_n, long mbr_n );
void	collect_gold( mbr_t *mbr );
void	divide_gold( void );
void	exp_party( long exp, bool_t flg_draw );
void	remove_mbr( mbr_t *mbr );
mbr_t	*get_mbr_nearest( long x, long y );
mbr_t	*get_mbr_near( long x, long y );
mbr_t	*get_mbr_disperse( mbr_t *mbr );
mbr_t	*get_mbr_randm( long x, long y );
mbr_t	*get_mbr_stagger( mbr_t *mbr );
bool_t	chk_already_mark( void *p, mbr_t *mbr );
char	*get_race_str( race_t *race );
char	*get_race_str_main( race_t *race );
char	*get_race_str_sub( race_t *race );
char	*get_race_name( race_t *race );
long	add_hp_mbr( mbr_t *mbr, long n );
bool_t	chk_not_exist_all_mbr( void );
mbr_t	**get_ls_mbr( void );
party_t	*get_party( void );
long	get_mbr_n( long x, long y );
mbr_t	*get_mbr( long x, long y );
flg_party_t	get_flg_party( void );
flg_party_t	set_flg_party( flg_party_t flg );
long	next_mbr( long mbr_n, long add );
long	next_ls_mbr( long ls_mbr_n, long add );
class_t	*get_class_tab( void );
bool_t	remove_class( long class_n );
bool_t	cmp_class( class_t *org, class_t *dst );
void	arrange_class( long class_n );
square_t	*get_square_mbr( void );
void	set_square_mbr( square_t *sq );
